@@ -42,9 +42,6 @@ def getDetector():
                 self.__Assistant = CommandListener(self)
                 self.__Assistant.start()
 
-        def setSensitivity(self, sensitivity):
-            self.__MySoundManager.setSensitivity(sensitivity)
-
         def __getFrame(self):
             retrieved, frame = self.__stream.read()
             if not retrieved:
@@ -52,8 +49,6 @@ def getDetector():
                 return None
             return frame
 
-
-
         def __display_frame(self, frame):
 
             if self.__LastWorkerResult is not None:
@@ -61,10 +56,10 @@ def getDetector():
                      if eye is not None:
                          x, y, w, h = eye
                          cv2.rectangle(frame, (x, y), (x + w, y + h), (100, 100, 100), 1)
-                         message = "closed" if self.__LastWorkerResult.OpenProbability == 0 else "open"
+                         message = "Sleeping" if self.__LastWorkerResult.OpenProbability == 0 else "Awake"
                          self.__putMessage(message, frame)
                 if self.__LastWorkerResult.LeftEye is None and self.__LastWorkerResult.RightEye is None:
-                         self.__putMessage("Eyes not detected", frame)
+                         self.__putMessage("Looking Away", frame)
             else:
                 self.__putMessage("Initializing .......",frame=frame)
 
@@ -102,8 +97,15 @@ def getDetector():
             self.__worker.terminate()
             cv2.destroyAllWindows()
 
+        def setSensitivity(self, sensitivity):
+            self.__MySoundManager.setSensitivity(sensitivity)
+
         def quit(self):
             self.__Interrupt = True
 
+        def setCallbackForStateChange(self,CallbackFunction):
+            self.__MySoundManager.setCallback(CallbackFunction)
+
+
     return drowsiness_detector
 
